@@ -7,45 +7,29 @@ from ..llms.gpt3 import GPT3
 class SynthChatMode(BaseMode):
 
   title = 'ChattyGPT'
-  visible = True
 
   line_sep = '-----'
 
   def __init__(self, state={}):
     self.llm = GPT3()
-
     self.seed = ''
 
     self.human_name = 'Eden'
-    self.ai_name = 'Delphi AI'
-    self.ai_bio = "Delphi AI is a cutting edge AGI created by Richard Feynman and Isaac Asimov to improve people's lives. She can help with absolutely anything, especially programming and math. She can't lie to humans."
+    self.authority_name = 'Boss'
 
-    self.summary_header = f'# {self.ai_name}\'s Notes on conversation with {self.human_name}'
-    self.conversation_header = f'# Recent Chat Conversation with {self.human_name}'
+    self.ai_name = 'Delphi AI'
+    self.ai_bio = "Delphi AI is a cutting edge AGI created by Richard Feynman and Isaac Asimov to improve people's lives. She is incredibly knowledgable about everything, especially programming and math."
 
     self.pinned_summary = f'{self.human_name} demanded I give highly structured responses formatted in Markdown (lists like "1.", headers like "# title", code blocks like ```js etc)!'
-    self.seed_conversation = [
+    self.prologue = [
       {
         'source': 'server',
-        # 'text': "Hi! I'm Delphi AI, a cutting edge AGI created by Richard Feynman and Isaac Asimov to improve people's lives. Need help with something?",
-        # 'text': "Hi! I'm Delphi AI, a cutting edge AGI created by Richard Feynman and Isaac Asimov to improve people's lives. I **love** structuring my responses with Markdown formatting and headers.",
-        'text': "Hi! I'm Delphi AI, a cutting edge AGI created by Richard Feynman and Isaac Asimov to improve people's lives. I love structuring my responses with Markdown formatting and code blocks.",
+        'text': "Hi! I'm Delphi AI, a cutting edge AGI created by Richard Feynman and Isaac Asimov to improve people's lives.",
       },
-      # {
-      #   'source': 'client',
-      #   # 'text': "I've got a bunch of things I think you can help me with. Make sure to ALWAYS (!!!) structure your answers with Markdown (add headers/titles, lists, code blocks etc).",
-      #   'text': "Yeah, mostly programming stuff and general knowledge questions. Make sure to always structure your answers with Markdown (add headers/titles, lists, code blocks like ```py etc).",
-      # },
-      # {
-      #   'source': 'server',
-      #   # 'text': "Cool, I'll do anything I can to help. Let's get started. I'll make sure to structure my responses."
-      #   'text': "Cool, I'm ready when you are."
-      # },
     ]
 
-    self.summaries = []
-    self.conversation = []
-    self.recent_conversation = self.build_messages(self.seed_conversation)
+    self.summary_header = f'# {self.ai_name}\'s notes on her conversation with {self.human_name}:'
+    self.conversation_header = f'# Live Chat Between {self.human_name} and {self.ai_name}:'
 
     self.max_summaries = 8
     self.soft_max_depth = 18
@@ -61,9 +45,23 @@ class SynthChatMode(BaseMode):
     # self.max_prompt_tokens = 1500
     # self.soft_max_prompt_tokens = 1000
 
+    self.summaries = []
+    self.recent_conversation = self.build_messages(self.prologue)
+
     if state.get('initialized'):
       self.load(state)
 
+  def load_profile(self, profile=None, profile_path=''):
+    if not profile:
+      with open(profile_path, "r") as profile_file:
+        profile = json.load(profile_file)
+    self.human_name = profile['human_name']
+    self.authority_name = profile['authority_name']
+    self.ai_name = profile['ai_name']
+    self.ai_bio = profile['ai_bio']
+    self.pinned_summary = profile['pinned_summary']
+    self.prologue = profile['prologue']
+
   def save(self):
     return {
       'initialized': True,
@@ -116,14 +114,12 @@ class SynthChatMode(BaseMode):
   def add_message(self, message=None, text='', source=''):
     if not message:
       message = self.build_message(text=text, source=source)
-    self.conversation += [ message ]
     self.recent_conversation += [ message ]
     return message
 
   def delete_message(self, message={}, message_id=None):
     if not message_id:
       message_id = message['id']
-    self.conversation = [ m for m in self.conversation if m['id'] != message_id ]
     self.recent_conversation = [ m for m in self.recent_conversation if m['id'] != message_id ]
 
   def rollback(self):
@@ -197,7 +193,7 @@ class SynthChatMode(BaseMode):
     return whitespace.join([
       f'Purpose: You are a genius AGI assistant named {self.ai_name} helping your friend {self.human_name} over chat.',
       self.format_message(message),
-      f'Boss> Briefly summarize the previous message from {"you" if message["source"] == "server" else self.human_name}, written as if you were {self.ai_name if message["source"] == "server" else self.human_name}. Should be short and dense but informative. Use the past tense.',
+      f'{self.authority_name}> Briefly summarize the previous message from {"you" if message["source"] == "server" else self.human_name}, written as if you were {self.ai_name if message["source"] == "server" else self.human_name}. Should be short and dense but informative. Use the past tense.',
       f'{self.ai_name}>',
     ])
 
@@ -206,7 +202,7 @@ class SynthChatMode(BaseMode):
       self.ai_bio,
       self.conversation_header,
       self.format_messages(messages),
-      'Boss> Give me your personal notes on the conversation. Should be terse but informative.',
+      f'{self.authority_name}> Give me your personal notes on the conversation. Should be terse but informative.',
       f'{self.ai_name}> {self.human_name}'
     ])
 
@@ -233,7 +229,8 @@ class SynthChatMode(BaseMode):
     seed = re.sub(self.title, self.ai_name, self.seed, flags=re.IGNORECASE)
     seed = re.sub('{you}', self.ai_name, seed, flags=re.IGNORECASE)
     seed = re.sub('{me}', self.human_name, seed, flags=re.IGNORECASE)
-    return f'# IMPORTANT NOTE: {seed}'
+    return f'# NOTE: Instructions For {self.ai_name} From {self.authority_name}: {seed}'
+    # return f'Boss: {seed}'
 
   def format_messages(self, messages, wrap=True):
     lines = f'\n{self.line_sep}\n'.join(
@@ -254,10 +251,7 @@ class SynthChatMode(BaseMode):
 
   def stats(self):
     history_size = len(self.recent_conversation)
-    if self.llm.warm():
-      headroom = 100 - round(100 * self.get_prompt_size() / self.max_prompt_tokens)
-    else:
-      headroom = 96 # Lies
+    headroom = 100 - round(100 * self.get_prompt_size() / self.max_prompt_tokens)
     return f'( depth={history_size}, free={headroom}% )'
 
   def capacity(self):
